pycep\_correios package
=======================

Submodules
----------

pycep\_correios\.cliente module
-------------------------------

.. automodule:: pycep_correios.cliente
    :members:
    :undoc-members:
    :show-inheritance:

pycep\_correios\.excecoes module
--------------------------------

.. automodule:: pycep_correios.excecoes
    :members:
    :undoc-members:
    :show-inheritance:

Module contents
---------------

.. automodule:: pycep_correios
    :members:
    :undoc-members:
    :show-inheritance:
